ApplicationSemanticModel

Struct ApplicationSemanticModel 

pub struct ApplicationSemanticModel {
Show 71 fields pub expression_graph: ExpressionGraph, pub semantic_types: SemanticTypeModel, pub components: Vec<ComponentNode>, pub contexts: BTreeMap<ContextId, ContextEntity>, pub providers: BTreeMap<ProviderId, ProviderEntity>, pub consumers: BTreeMap<ConsumerId, ConsumerEntity>, pub forms: BTreeMap<FormId, FormEntity>, pub resource_endpoint_resolutions: Vec<ResourceEndpointResolution>, pub opaque_action_resolutions: Vec<OpaqueActionResolution>, pub resource_declarations: BTreeMap<ResourceId, ResourceDeclaration>, pub resource_activations: BTreeMap<ResourceActivationId, ResourceActivation>, pub form_field_declaration_candidates: Vec<FormFieldDeclarationCandidate>, pub form_fields: BTreeMap<FieldId, FormFieldEntity>, pub form_field_binding_candidates: Vec<FormFieldBindingCandidate>, pub form_field_bindings: BTreeMap<FieldBindingId, FormFieldBinding>, pub form_ownership: FormOwnershipGraph, pub validation_rule_candidates: Vec<ValidationRuleCandidate>, pub validation_rules: BTreeMap<ValidationRuleId, ValidationRule>, pub validation_graph: ValidationGraph, pub validation_dependency_plans: ValidationDependencyPlans, pub form_tracking: FormTrackingProducts, pub submissions: SubmissionProducts, pub submission_host_candidates: Vec<SubmissionHostCandidate>, pub submission_hosts: BTreeMap<SubmissionHostId, SubmissionHost>, pub serialization: SerializationProducts, pub reset: ResetProducts, pub form_ir: FormIrReport, pub optimized_form_ir: OptimizedFormIrReport, pub runtime_forms: RuntimeFormRegistry, pub slots: BTreeMap<SlotId, SlotEntity>, pub component_invocations: BTreeMap<ComponentInvocationId, ComponentInvocationEntity>, pub component_instance_plan: ComponentInstancePlan, pub component_instance_scope: ComponentInstanceScopeGraph, pub component_composition: ComponentCompositionAnalysis, pub component_initialization: ComponentInitializationPlan, pub component_ir: ComponentIrReport, pub component_ir_optimization: OptimizedComponentIrReport, pub instance_context: InstanceContextRegistry, pub slot_content_fragments: BTreeMap<SlotContentFragmentId, SlotContentFragment>, pub slot_outlets: BTreeMap<SlotOutletId, SlotOutlet>, pub slot_bindings: SlotBindingRegistry, pub composition_types: CompositionTypeProducts, pub context_declaration_candidates: ContextDeclarationCandidateRegistry, pub context_ownership: ContextOwnershipGraph, pub context_dependency: ContextDependencyGraph, pub context_lifetime: ContextLifetimeAnalysis, pub context_evaluation: ContextEvaluationPlan, pub component_scope: ComponentScopeGraph, pub context_resolutions: BTreeMap<ConsumerId, ContextResolution>, pub context_types: BTreeMap<ContextId, ContextTypeRecord>, pub provider_types: BTreeMap<ProviderId, ProviderTypeRecord>, pub consumer_types: BTreeMap<ConsumerId, ConsumerTypeRecord>, pub context_binding_types: BTreeMap<ConsumerId, ContextBindingTypeRecord>, pub duplicate_provider_declarations: Vec<DuplicateProviderDeclaration>, pub computed_values: BTreeMap<SemanticId, ComputedValue>, pub effects: BTreeMap<SemanticId, Effect>, pub effect_reactive_analysis: BTreeMap<SemanticId, EffectReactiveAnalysis>, pub effect_trigger_plan: EffectTriggerPlan, pub effect_execution_plan: EffectExecutionPlan, pub effect_bodies: BTreeMap<SemanticId, EffectBody>, pub effect_statements: BTreeMap<SemanticId, EffectStatement>, pub reactive_graph: IrReactiveGraph, pub reactive_transitive_analysis: IrReactiveTransitiveAnalysis, pub reactive_cycle_analysis: IrReactiveCycleAnalysis, pub computed_evaluation_plan: IrComputedEvaluationPlan, pub templates: Vec<TemplateNode>, pub template_entities: Vec<TemplateSemanticEntity>, pub diagnostics: Vec<ComponentDiagnostic>, pub ownership: BTreeMap<SemanticId, SemanticOwner>, pub references: Vec<SemanticReference>, pub provenance: BTreeMap<SemanticId, SourceProvenance>,
}
Application-level semantic data assembled from the compiler’s existing graphs.

Fields

expression_graph: ExpressionGraphsemantic_types: SemanticTypeModelcomponents: Vec<ComponentNode>contexts: BTreeMap<ContextId, ContextEntity>providers: BTreeMap<ProviderId, ProviderEntity>consumers: BTreeMap<ConsumerId, ConsumerEntity>forms: BTreeMap<FormId, FormEntity>resource_endpoint_resolutions: Vec<ResourceEndpointResolution>

Integrity-checked package endpoint selections for Resource declaration and activation lowering.

opaque_action_resolutions: Vec<OpaqueActionResolution>

Integrity-checked opaque terminal package selections. These are resolution facts only until a later artifact/runtime lowering product consumes them.

resource_declarations: BTreeMap<ResourceId, ResourceDeclaration>

Validated Resource declaration products projected into the canonical runtime activation artifact when a host supplies exact module locations.

resource_activations: BTreeMap<ResourceActivationId, ResourceActivation>form_field_declaration_candidates: Vec<FormFieldDeclarationCandidate>form_fields: BTreeMap<FieldId, FormFieldEntity>form_field_binding_candidates: Vec<FormFieldBindingCandidate>form_field_bindings: BTreeMap<FieldBindingId, FormFieldBinding>form_ownership: FormOwnershipGraphvalidation_rule_candidates: Vec<ValidationRuleCandidate>validation_rules: BTreeMap<ValidationRuleId, ValidationRule>validation_graph: ValidationGraphvalidation_dependency_plans: ValidationDependencyPlansform_tracking: FormTrackingProductssubmissions: SubmissionProductssubmission_host_candidates: Vec<SubmissionHostCandidate>submission_hosts: BTreeMap<SubmissionHostId, SubmissionHost>serialization: SerializationProductsreset: ResetProductsform_ir: FormIrReportoptimized_form_ir: OptimizedFormIrReportruntime_forms: RuntimeFormRegistryslots: BTreeMap<SlotId, SlotEntity>component_invocations: BTreeMap<ComponentInvocationId, ComponentInvocationEntity>component_instance_plan: ComponentInstancePlancomponent_instance_scope: ComponentInstanceScopeGraphcomponent_composition: ComponentCompositionAnalysiscomponent_initialization: ComponentInitializationPlancomponent_ir: ComponentIrReportcomponent_ir_optimization: OptimizedComponentIrReportinstance_context: InstanceContextRegistryslot_content_fragments: BTreeMap<SlotContentFragmentId, SlotContentFragment>slot_outlets: BTreeMap<SlotOutletId, SlotOutlet>slot_bindings: SlotBindingRegistrycomposition_types: CompositionTypeProductscontext_declaration_candidates: ContextDeclarationCandidateRegistrycontext_ownership: ContextOwnershipGraphcontext_dependency: ContextDependencyGraphcontext_lifetime: ContextLifetimeAnalysiscontext_evaluation: ContextEvaluationPlancomponent_scope: ComponentScopeGraphcontext_resolutions: BTreeMap<ConsumerId, ContextResolution>context_types: BTreeMap<ContextId, ContextTypeRecord>provider_types: BTreeMap<ProviderId, ProviderTypeRecord>consumer_types: BTreeMap<ConsumerId, ConsumerTypeRecord>context_binding_types: BTreeMap<ConsumerId, ContextBindingTypeRecord>duplicate_provider_declarations: Vec<DuplicateProviderDeclaration>computed_values: BTreeMap<SemanticId, ComputedValue>effects: BTreeMap<SemanticId, Effect>effect_reactive_analysis: BTreeMap<SemanticId, EffectReactiveAnalysis>effect_trigger_plan: EffectTriggerPlaneffect_execution_plan: EffectExecutionPlaneffect_bodies: BTreeMap<SemanticId, EffectBody>effect_statements: BTreeMap<SemanticId, EffectStatement>reactive_graph: IrReactiveGraphreactive_transitive_analysis: IrReactiveTransitiveAnalysisreactive_cycle_analysis: IrReactiveCycleAnalysiscomputed_evaluation_plan: IrComputedEvaluationPlantemplates: Vec<TemplateNode>template_entities: Vec<TemplateSemanticEntity>diagnostics: Vec<ComponentDiagnostic>ownership: BTreeMap<SemanticId, SemanticOwner>references: Vec<SemanticReference>provenance: BTreeMap<SemanticId, SourceProvenance>

Implementations

Source

impl ApplicationSemanticModel

pub fn entity(&self, id: &SemanticId) -> Option<SemanticEntity<'_>>

pub fn component(&self, id: &SemanticId) -> Option<&ComponentNode>

pub fn template(&self, id: &SemanticId) -> Option<&TemplateNode>

pub fn computed_value(&self, id: &SemanticId) -> Option<&ComputedValue>

pub fn contexts(&self) -> Vec<&ContextEntity>

pub fn context(&self, id: &ContextId) -> Option<&ContextEntity>

pub fn forms(&self) -> Vec<&FormEntity>

pub fn form(&self, id: &FormId) -> Option<&FormEntity>

pub fn form_fields(&self) -> Vec<&FormFieldEntity>

pub fn form_field(&self, id: &FieldId) -> Option<&FormFieldEntity>

pub fn form_field_declaration_candidates( &self, ) -> &[FormFieldDeclarationCandidate]

pub fn form_field_binding_candidates(&self) -> &[FormFieldBindingCandidate]

pub fn form_field_bindings(&self) -> Vec<&FormFieldBinding>

pub fn form_field_binding( &self, id: &FieldBindingId, ) -> Option<&FormFieldBinding>

pub const fn form_ownership(&self) -> &FormOwnershipGraph

pub fn validation_rule_candidates(&self) -> &[ValidationRuleCandidate]

pub fn validation_candidates_of( &self, field: &FieldId, ) -> Vec<&ValidationRuleCandidate>

pub fn validation_rule(&self, id: &ValidationRuleId) -> Option<&ValidationRule>

pub fn validation_rules(&self) -> Vec<&ValidationRule>

pub const fn validation_graph(&self) -> &ValidationGraph

pub const fn validation_dependency_plans(&self) -> &ValidationDependencyPlans

pub const fn form_tracking(&self) -> &FormTrackingProducts

pub const fn submissions(&self) -> &SubmissionProducts

pub const fn serialization(&self) -> &SerializationProducts

pub const fn reset(&self) -> &ResetProducts

pub fn form_declaration_candidates(&self) -> Vec<&FormDeclarationCandidate>

pub const fn context_declaration_candidates( &self, ) -> &ContextDeclarationCandidateRegistry

pub fn contexts_owned_by(&self, component: &SemanticId) -> Vec<&ContextId>

pub fn context_for_authored_field( &self, field: &SemanticId, ) -> Option<&ContextId>

pub fn providers(&self) -> Vec<&ProviderEntity>

pub fn provider(&self, id: &ProviderId) -> Option<&ProviderEntity>

pub fn providers_owned_by(&self, component: &SemanticId) -> Vec<&ProviderId>

pub fn providers_for_context(&self, context: &ContextId) -> Vec<&ProviderId>

pub fn provider_for_authored_field( &self, field: &SemanticId, ) -> Option<&ProviderId>

pub fn consumers(&self) -> Vec<&ConsumerEntity>

pub fn consumer(&self, id: &ConsumerId) -> Option<&ConsumerEntity>

pub fn consumers_owned_by(&self, component: &SemanticId) -> Vec<&ConsumerId>

pub fn consumers_for_context(&self, context: &ContextId) -> Vec<&ConsumerId>

pub fn consumer_for_authored_field( &self, field: &SemanticId, ) -> Option<&ConsumerId>

pub fn slots(&self) -> Vec<&SlotEntity>

pub fn slot(&self, id: &SlotId) -> Option<&SlotEntity>

pub fn slots_owned_by(&self, component: &SemanticId) -> Vec<&SlotId>

pub fn slot_for_authored_field(&self, field: &SemanticId) -> Option<&SlotId>

pub fn component_invocations(&self) -> Vec<&ComponentInvocationEntity>

pub fn component_invocation( &self, id: &ComponentInvocationId, ) -> Option<&ComponentInvocationEntity>

pub fn component_invocations_owned_by( &self, component: &SemanticId, ) -> Vec<&ComponentInvocationId>

pub fn component_instance( &self, id: &ComponentInstanceId, ) -> Option<&ComponentInstance>

pub fn component_build_roots(&self) -> Vec<&ComponentBuildRoot>

pub fn component_instances(&self) -> Vec<&ComponentInstance>

pub fn blocked_component_instances(&self) -> Vec<&BlockedComponentInstancePlan>

pub fn blocked_component_instance( &self, id: &ComponentInstanceId, ) -> Option<&BlockedComponentInstancePlan>

pub fn component_instances_for_definition( &self, component: &SemanticId, ) -> Vec<&ComponentInstance>

pub const fn component_instance_scope_graph( &self, ) -> &ComponentInstanceScopeGraph

pub const fn component_composition_analysis( &self, ) -> &ComponentCompositionAnalysis

pub const fn component_initialization_plan( &self, ) -> &ComponentInitializationPlan

pub const fn component_ir_report(&self) -> &ComponentIrReport

pub const fn optimized_component_ir_report(&self) -> &OptimizedComponentIrReport

pub const fn instance_context_registry(&self) -> &InstanceContextRegistry

pub fn slot_content_fragments(&self) -> Vec<&SlotContentFragment>

pub const fn slot_binding_registry(&self) -> &SlotBindingRegistry

pub const fn composition_type_products(&self) -> &CompositionTypeProducts

pub fn slot_bindings(&self) -> Vec<&SlotBinding>

pub fn slot_binding(&self, id: &SlotBindingId) -> Option<&SlotBinding>

pub fn slot_bindings_for_callee( &self, callee: &ComponentInstanceId, ) -> Vec<&SlotBinding>

pub fn slot_content_fragment( &self, id: &SlotContentFragmentId, ) -> Option<&SlotContentFragment>

pub fn slot_content_fragments_for( &self, invocation: &ComponentInvocationId, ) -> Vec<&SlotContentFragment>

pub fn slot_outlets(&self) -> Vec<&SlotOutlet>

pub fn slot_outlet(&self, id: &SlotOutletId) -> Option<&SlotOutlet>

pub fn slot_outlets_owned_by( &self, component: &SemanticId, ) -> Vec<&SlotOutletId>

pub fn context_resolution( &self, consumer: &ConsumerId, ) -> Option<&ContextResolution>

pub const fn context_ownership_graph(&self) -> &ContextOwnershipGraph

pub const fn context_dependency_graph(&self) -> &ContextDependencyGraph

pub const fn context_lifetime_analysis(&self) -> &ContextLifetimeAnalysis

pub const fn context_evaluation_plan(&self) -> &ContextEvaluationPlan

pub fn resolved_provider(&self, consumer: &ConsumerId) -> Option<&ProviderId>

pub fn consumers_resolved_to(&self, provider: &ProviderId) -> Vec<&ConsumerId>

pub fn consumers_using_default(&self, context: &ContextId) -> Vec<&ConsumerId>

pub fn unresolved_context_consumers(&self) -> Vec<&ConsumerId>

pub fn context_type(&self, context: &ContextId) -> Option<&ContextTypeRecord>

pub fn provider_type( &self, provider: &ProviderId, ) -> Option<&ProviderTypeRecord>

pub fn consumer_type( &self, consumer: &ConsumerId, ) -> Option<&ConsumerTypeRecord>

pub fn context_binding_type( &self, consumer: &ConsumerId, ) -> Option<&ContextBindingTypeRecord>

pub fn runtime_eligible_context_binding(&self, consumer: &ConsumerId) -> bool

pub fn effect(&self, id: &SemanticId) -> Option<&Effect>

pub fn effect_body(&self, effect: &SemanticId) -> Option<&EffectBody>

pub fn effect_reactive_analysis( &self, effect: &SemanticId, ) -> Option<&EffectReactiveAnalysis>

pub const fn effect_trigger_plan(&self) -> &EffectTriggerPlan

pub const fn effect_execution_plan(&self) -> &EffectExecutionPlan

pub fn effect_statement_type( &self, statement: &SemanticId, ) -> Option<&EffectStatementTypeRecord>

Returns F4 typing facts for one canonical effect statement.

pub fn effect_statement(&self, id: &SemanticId) -> Option<&EffectStatement>

pub fn template_entity( &self, id: &SemanticId, ) -> Option<&TemplateSemanticEntity>

pub fn template_entities_for( &self, template: &SemanticId, ) -> Vec<&TemplateSemanticEntity>

pub fn owner(&self, id: &SemanticId) -> Option<&SemanticOwner>

pub fn parent_of(&self, id: &SemanticId) -> Option<&SemanticId>

pub fn ancestors_of(&self, id: &SemanticId) -> Vec<&SemanticId>

pub fn provenance(&self, id: &SemanticId) -> Option<&SourceProvenance>

pub fn expression(&self, id: &SemanticId) -> Option<&ExpressionNode>

pub fn expression_root(&self, owner: &SemanticId) -> Option<&SemanticId>

pub fn expressions_for(&self, owner: &SemanticId) -> Vec<&ExpressionNode>

pub fn expression_dependencies(&self, id: &SemanticId) -> Vec<&SemanticId>

pub fn expression_dependents(&self, id: &SemanticId) -> Vec<&ExpressionNode>

pub fn expression_owner(&self, id: &SemanticId) -> Option<&SemanticId>

pub fn expression_provenance( &self, id: &SemanticId, ) -> Option<&SourceProvenance>

pub fn semantic_type_of(&self, id: &SemanticId) -> Option<&SemanticType>

pub fn expression_type(&self, id: &SemanticId) -> Option<&SemanticType>

pub fn type_declarations( &self, semantic_type: &SemanticType, ) -> Vec<&SemanticTypeAssignment>

pub fn type_usages( &self, semantic_type: &SemanticType, ) -> Vec<&SemanticTypeAssignment>

pub fn serialization_compatibility_of( &self, id: &SemanticId, ) -> Option<SerializationCompatibility>

pub fn is_type_assignable( &self, source: &SemanticId, target: &SemanticId, ) -> Option<bool>

pub fn expressions_in_file(&self, path: &Path) -> Vec<&ExpressionNode>

pub fn expressions_at(&self, path: &Path, offset: usize) -> Vec<&ExpressionNode>

pub fn application_roots(&self) -> Vec<&SemanticId>

pub fn children_of(&self, owner: &SemanticId) -> Vec<&SemanticId>

pub fn descendants_of(&self, owner: &SemanticId) -> Vec<&SemanticId>

pub fn entities_of_kind(&self, kind: SemanticEntityKind) -> Vec<&SemanticId>

pub fn entities_in_file(&self, path: &Path) -> Vec<&SemanticId>

pub fn entities_at(&self, path: &Path, offset: usize) -> Vec<&SemanticId>

pub fn references_of_kind( &self, kind: SemanticReferenceKind, ) -> Vec<&SemanticReference>

pub fn references_in_file(&self, path: &Path) -> Vec<&SemanticReference>

pub fn references_at( &self, path: &Path, offset: usize, ) -> Vec<&SemanticReference>

pub fn references_from(&self, id: &SemanticId) -> Vec<&SemanticReference>

pub fn references_to(&self, id: &SemanticId) -> Vec<&SemanticReference>