pub struct FormDeclarationCandidate {Show 17 fields
pub id: FormDeclarationCandidateId,
pub owner_component: Option<SemanticId>,
pub form_id: Option<FormId>,
pub authored_field: Option<SemanticId>,
pub authored_name: Option<String>,
pub declaration_kind: AuthoredDeclarationKind,
pub decorator_invoked: bool,
pub decorator_argument_count: usize,
pub decorator_argument_provenance: Vec<SourceProvenance>,
pub declaration_only: bool,
pub declared_type: Option<DeclaredStateType>,
pub conflicting_decorators: Vec<String>,
pub decorator_provenance: SourceProvenance,
pub name_provenance: Option<SourceProvenance>,
pub initializer_provenance: Option<SourceProvenance>,
pub provenance: SourceProvenance,
pub status: FormDeclarationStatus,
}Expand description
Immutable I2 declaration candidate retained before canonical Form
construction. form_id is present only when owner and authored field name
are independently canonical, even when another declaration rule fails.
Fields
id: FormDeclarationCandidateIdowner_component: Option<SemanticId>form_id: Option<FormId>declaration_kind: AuthoredDeclarationKinddecorator_invoked: booldecorator_argument_count: usizedecorator_argument_provenance: Vec<SourceProvenance>declaration_only: booldeclared_type: Option<DeclaredStateType>conflicting_decorators: Vec<String>decorator_provenance: SourceProvenancename_provenance: Option<SourceProvenance>initializer_provenance: Option<SourceProvenance>provenance: SourceProvenancestatus: FormDeclarationStatusImplementations
Sourceimpl FormDeclarationCandidate
impl FormDeclarationCandidate
pub fn violations(&self) -> &[FormDeclarationViolation]