Module component_invocation

Module component_invocation 

Structs

ComponentInvocationEntity
One immutable compiler-owned use of a component definition in a caller template.

Enums

ComponentInvocationResolutionStatus

Functions

collect_component_invocations
Lower PascalCase component uses from canonical template traversal and binding facts.