pub struct ExpressionGraph {
pub roots: BTreeMap<SemanticId, SemanticId>,
pub nodes: BTreeMap<SemanticId, ExpressionNode>,
}Expand description
Canonical compiler-owned graph for all lowered state initializer and computed expressions.
Fields
roots: BTreeMap<SemanticId, SemanticId>nodes: BTreeMap<SemanticId, ExpressionNode>Implementations
Sourceimpl ExpressionGraph
impl ExpressionGraph
Sourcepub fn from_components(
components: &[ComponentNode],
provenance: &BTreeMap<SemanticId, SourceProvenance>,
) -> Self
pub fn from_components( components: &[ComponentNode], provenance: &BTreeMap<SemanticId, SourceProvenance>, ) -> Self
Panics
Panics when an expression owner has no canonical source provenance.
pub fn root_for(&self, owner: &SemanticId) -> Option<&SemanticId>
pub fn node(&self, id: &SemanticId) -> Option<&ExpressionNode>
pub fn nodes_for(&self, owner: &SemanticId) -> Vec<&ExpressionNode>
pub fn dependencies_of(&self, id: &SemanticId) -> Vec<&SemanticId>
pub fn dependents_of(&self, id: &SemanticId) -> Vec<&ExpressionNode>
pub fn owner_of(&self, id: &SemanticId) -> Option<&SemanticId>
pub fn provenance_of(&self, id: &SemanticId) -> Option<&SourceProvenance>
pub fn nodes_in_file(&self, path: &Path) -> Vec<&ExpressionNode>
pub fn nodes_at(&self, path: &Path, offset: usize) -> Vec<&ExpressionNode>
pub fn evaluate( &self, owner: &SemanticId, ) -> Option<Result<SerializableValue, ConstantEvaluationError>>
pub fn render(&self, owner: &SemanticId) -> Option<String>