Module form_diagnostics

Module form_diagnostics 

Structs

FormDiagnosticReservation
A Phase I diagnostic code reserved before form syntax is lowered.

Constants

FORM_DIAGNOSTIC_RESERVATIONS
The next contiguous public compiler diagnostic range after Phase H.

Functions

collect_form_diagnostics
Project I18 Forms diagnostics exclusively from retained compiler products.