pub struct FormFieldEntity {Show 16 fields
pub id: FieldId,
pub owner_form: FormId,
pub owner_component: SemanticId,
pub authored_field: SemanticId,
pub name: String,
pub path: Vec<String>,
pub semantic_type: SemanticType,
pub type_assignment: SemanticTypeAssignment,
pub initial_value: SerializableValue,
pub declaration_order: usize,
pub provenance: SourceProvenance,
pub form_designator_provenance: SourceProvenance,
pub field_name_provenance: SourceProvenance,
pub type_provenance: SourceProvenance,
pub initializer_provenance: SourceProvenance,
pub boundary: ExecutionBoundary,
}Expand description
First-class immutable compiler-owned Form Field declaration.
Fields
id: FieldIdowner_form: FormIdowner_component: SemanticIdname: Stringpath: Vec<String>Compiler-issued serialized leaf path. Current one-argument Fields use their name as a single root segment; N7-B will admit retained nested segments only with the complete artifact/runtime contract.
semantic_type: SemanticTypetype_assignment: SemanticTypeAssignmentinitial_value: SerializableValuedeclaration_order: usizeprovenance: SourceProvenanceform_designator_provenance: SourceProvenancefield_name_provenance: SourceProvenancetype_provenance: SourceProvenanceinitializer_provenance: SourceProvenanceboundary: ExecutionBoundaryTrait Implementations
Sourceimpl Clone for FormFieldEntity
impl Clone for FormFieldEntity
Sourcefn clone(&self) -> FormFieldEntity
fn clone(&self) -> FormFieldEntity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormFieldEntity
impl Debug for FormFieldEntity
impl Eq for FormFieldEntity
Sourceimpl PartialEq for FormFieldEntity
impl PartialEq for FormFieldEntity
impl StructuralPartialEq for FormFieldEntity