pub struct SerializedStructuralComponentProgram {
pub region: String,
pub host_component: String,
pub host_node: String,
pub host_template_entity: String,
pub conditional_host_fragments: Vec<SerializedStructuralConditionalHostFragments>,
pub keyed_host_fragments: Vec<SerializedStructuralKeyedHostFragment>,
pub template_occurrences: Vec<SerializedStructuralTemplateOccurrence>,
pub template_instances: Vec<String>,
pub destroy_order: Vec<String>,
pub create_order: Vec<String>,
}Fields
region: Stringhost_component: StringCanonical component that owns the conditional or keyed-list host.
host_node: StringExact compiler-generated template node ID for the structural host.
host_template_entity: StringExact semantic template entity for the conditional or keyed-list host.
conditional_host_fragments: Vec<SerializedStructuralConditionalHostFragments>Compiler-rendered conditional branches for initially static host instances. Keyed-list and nested host scopes remain absent until their complete compiler input scopes have an authored product.
keyed_host_fragments: Vec<SerializedStructuralKeyedHostFragment>Compiler-rendered keyed item fragments with exact structural invocation anchors. They remain inactive until keyed materialization is admitted.
template_occurrences: Vec<SerializedStructuralTemplateOccurrence>template_instances: Vec<String>destroy_order: Vec<String>create_order: Vec<String>Trait Implementations
Sourceimpl Clone for SerializedStructuralComponentProgram
impl Clone for SerializedStructuralComponentProgram
Sourcefn clone(&self) -> SerializedStructuralComponentProgram
fn clone(&self) -> SerializedStructuralComponentProgram
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SerializedStructuralComponentProgram
impl<'de> Deserialize<'de> for SerializedStructuralComponentProgram
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SerializedStructuralComponentProgram
impl StructuralPartialEq for SerializedStructuralComponentProgram