pub struct FormOwnershipGraphId(/* private fields */);Expand description
Stable identity for the declaration-level Form ownership projection of one canonical application/build-root set.
Implementations
Sourceimpl FormOwnershipGraphId
impl FormOwnershipGraphId
Sourcepub fn for_build_roots<'a>(
roots: impl IntoIterator<Item = &'a ComponentRootId>,
) -> Self
pub fn for_build_roots<'a>( roots: impl IntoIterator<Item = &'a ComponentRootId>, ) -> Self
Derives one product identity from the existing canonical build-root identities. The root set is sorted and deduplicated so file input order cannot affect the result.
pub const fn as_semantic_id(&self) -> &SemanticId
pub fn as_str(&self) -> &str