pub struct SemanticPackageOpaqueTerminal {
pub execution_boundary: SemanticPackageOpaqueExecutionBoundary,
pub resume: SemanticPackageOpaqueResumePolicy,
}Expand description
Closed contract for a no-input, no-output opaque terminal export.
This records how the application may use a package without giving the compiler authority to inspect its implementation.
Fields
execution_boundary: SemanticPackageOpaqueExecutionBoundaryresume: SemanticPackageOpaqueResumePolicyTrait Implementations
Sourceimpl Clone for SemanticPackageOpaqueTerminal
impl Clone for SemanticPackageOpaqueTerminal
Sourcefn clone(&self) -> SemanticPackageOpaqueTerminal
fn clone(&self) -> SemanticPackageOpaqueTerminal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SemanticPackageOpaqueTerminal
impl<'de> Deserialize<'de> for SemanticPackageOpaqueTerminal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SemanticPackageOpaqueTerminal
impl StructuralPartialEq for SemanticPackageOpaqueTerminal