pub struct SemanticPackageResourceEndpoint {
pub execution_boundary: SemanticPackageResourceExecutionBoundary,
pub cancellation: SemanticPackageResourceCancellation,
pub resume: SemanticPackageResourceResumePolicy,
}Expand description
Closed semantic contract for an executable Resource package export.
The compiler still does not execute or inspect package implementation. This metadata is the prerequisite for later Resource source lowering.
Fields
execution_boundary: SemanticPackageResourceExecutionBoundarycancellation: SemanticPackageResourceCancellationresume: SemanticPackageResourceResumePolicyTrait Implementations
Sourceimpl Clone for SemanticPackageResourceEndpoint
impl Clone for SemanticPackageResourceEndpoint
Sourcefn clone(&self) -> SemanticPackageResourceEndpoint
fn clone(&self) -> SemanticPackageResourceEndpoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SemanticPackageResourceEndpoint
impl<'de> Deserialize<'de> for SemanticPackageResourceEndpoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SemanticPackageResourceEndpoint
impl StructuralPartialEq for SemanticPackageResourceEndpoint