pub fn validate_state_instance_storage_registry(
model: &ApplicationSemanticModel,
ir: &IntermediateRepresentation,
registry: &StateInstanceStorageRegistry,
) -> Result<(), String>Expand description
Errors
Returns an error when the retained registry is not the exact canonical projection of component instances and definition-level IR storage.