pub struct SemanticId(/* private fields */);Expand description
Globally stable identity for a compiler semantic entity.
IDs use the component element name when available because it is the application-facing component identity. Invalid components without an element declaration fall back to their class name so diagnostics and later ASM validation can still refer to them deterministically.
Implementations
Sourceimpl SemanticId
impl SemanticId
pub fn component_root(component: &Self) -> Self
pub fn component(element_name: Option<&str>, class_name: &str) -> Self
pub fn component_in_module( module_path: impl AsRef<Path>, element_name: Option<&str>, class_name: &str, ) -> Self
pub fn type_alias_in_module(module_path: impl AsRef<Path>, name: &str) -> Self
pub fn state_field(&self, name: &str) -> Self
pub fn method(&self, name: &str) -> Self
pub fn computed(&self, name: &str) -> Self
pub fn effect(&self, name: &str) -> Self
pub fn context(&self, name: &str) -> Self
pub fn context_field(&self, name: &str) -> Self
pub fn provider(&self, name: &str) -> Self
pub fn provider_field(&self, name: &str) -> Self
pub fn consumer(&self, name: &str) -> Self
pub fn consumer_field(&self, name: &str) -> Self
pub fn form(&self, name: &str) -> Self
pub fn resource(&self, name: &str) -> Self
pub fn route_loader(&self, name: &str) -> Self
pub fn server_action(&self, name: &str) -> Self
pub fn form_field(&self, name: &str) -> Self
pub fn form_declaration_candidate_in_module( module_path: impl AsRef<Path>, position: usize, ) -> Self
pub fn form_field_declaration_candidate_in_module( module_path: impl AsRef<Path>, position: usize, ) -> Self
pub fn form_field_binding_candidate_in_module( module_path: impl AsRef<Path>, position: usize, ) -> Self
pub fn validation_rule_candidate_in_module( module_path: impl AsRef<Path>, position: usize, ) -> Self
pub fn submission_declaration_candidate_in_module( module_path: impl AsRef<Path>, position: usize, ) -> Self
pub fn field(&self, name: &str) -> Self
pub fn validation_rule(&self, ordinal: usize) -> Self
pub fn validation_plan(&self) -> Self
pub fn field_dependency(&self, source_field: &Self) -> Self
pub fn dirty_tracking_plan(&self) -> Self
pub fn touched_tracking_plan(&self) -> Self
pub fn field_tracking(&self) -> Self
pub fn submission_plan(&self) -> Self
pub fn serialization_plan(&self) -> Self
pub fn reset_plan(&self) -> Self
pub fn field_reset_operation(&self, field: &Self) -> Self
pub fn form_instance(&self, form: &str) -> Self
pub fn slot(&self, name: &str) -> Self
pub fn slot_field(&self, name: &str) -> Self
pub fn slot_declaration_candidate(&self, position: usize) -> Self
pub fn context_declaration_candidate(&self, position: usize) -> Self
Sourcepub fn context_provider_function(&self) -> Self
pub fn context_provider_function(&self) -> Self
Stable generated-function identity for a Provider Context source.
Sourcepub fn context_default_function(&self) -> Self
pub fn context_default_function(&self) -> Self
Stable generated-function identity for a Context-default source.
Sourcepub fn context_consumer_load(&self) -> Self
pub fn context_consumer_load(&self) -> Self
Stable semantic origin used only to scope a retained Context Consumer load value.
pub fn effect_activation_slot(&self, name: &str) -> Self
pub fn effect_statement(&self, index: usize) -> Self
pub fn action(&self, method: &str, index: usize) -> Self
pub fn action_batch(&self, method: &str) -> Self
pub fn opaque_activation(&self, method: &str) -> Self
pub fn local_variable(&self, name: &str, index: usize) -> Self
pub fn parameter(&self, name: &str, index: usize) -> Self
pub fn expression(&self, path: &str) -> Self
pub fn semantic_type(&self) -> Self
pub fn event_handler(&self, event: &str, index: usize) -> Self
pub fn template(&self) -> Self
pub fn template_entity(&self, kind: &str, path: &str) -> Self
pub fn component_invocation(&self, target: &str) -> Self
Sourcepub fn layout_composition_invocation(
&self,
route: &Self,
position: usize,
) -> Self
pub fn layout_composition_invocation( &self, route: &Self, position: usize, ) -> Self
Compiler-issued identity for one automatic file-route layout edge.
pub fn template_position(&self) -> Self
pub fn field_binding(&self, field: &str) -> Self
pub fn slot_content_fragment(&self, slot_name: &str) -> Self
pub fn slot_outlet(&self, slot_name: &str) -> Self
pub fn slot_binding(&self, binding_key: &str) -> Self
pub fn component_instance_invocation(&self, invocation: &str) -> Self
pub fn component_structural_region(&self, kind: &str) -> Self
pub fn as_str(&self) -> &str